@@ -62,14 +62,14 @@ var (
 	ShellExitNum int
 )
 
-func DefineMethod(name string, fn func(*Process) error, StdinDataType, StdoutDataType string) {
+func DefineFunction(name string, fn func(*Process) error, StdoutDataType string) {
 	GoFunctions[name] = fn
-	MethodStdin.Define(name, StdinDataType)
 	MethodStdout.Define(name, StdoutDataType)
 }
 
-func DefineFunction(name string, fn func(*Process) error, StdoutDataType string) {
+func DefineMethod(name string, fn func(*Process) error, StdinDataType, StdoutDataType string) {
 	GoFunctions[name] = fn
+	MethodStdin.Define(name, StdinDataType)
 	MethodStdout.Define(name, StdoutDataType)
 }
 
@@ -181,8 +181,7 @@ func createProcess(p *Process, isMethod bool) {
 	p.State.Set(state.Assigned)
 
 	// Lets run `pipe` and `test` ahead of time to fudge the use of named pipes
-	if name == "pipe:" || name == "test:" ||
-		name == "pipe" || name == "test" {
+	if name == "pipe" || name == "test" {
 		//err := ParseParameters(p, &p.Parameters)
 		_, params, err := ParseStatementParameters(p.raw, p)
 		if err != nil {
